<?php

namespace Drupal\quick_shortcuts\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configuration for the shortcuts module.
 */
class QuickShortcutsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'quick_shortcuts_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['quick_shortcuts.settings'];
  }

  /**
   * Get available Claro theme icons.
   */
  private function getAvailableIcons() {
    return [
      'admin' => $this->t('Admin'),
      'content' => $this->t('Contenido'),
      'module' => $this->t('Módulo'),
      'system' => $this->t('Sistema'),
      'structure' => $this->t('Estructura'),
      'people' => $this->t('Personas'),
      'configuration' => $this->t('Configuración'),
      'reports' => $this->t('Reportes'),
      'help' => $this->t('Ayuda'),
      'close' => $this->t('Cerrar'),
      'edit' => $this->t('Editar'),
      'move' => $this->t('Mover'),
      'shortcut' => $this->t('Atajo'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('quick_shortcuts.settings');
    $shortcuts_string = $config->get('shortcuts');
    
    // Convert stored shortcuts string to array
    $shortcuts = [];
    if (!empty($shortcuts_string)) {
      $lines = explode("\n", $shortcuts_string);
      foreach ($lines as $line) {
        $parts = explode('|', $line);
        if (count($parts) >= 2) {
          $shortcuts[] = [
            'title' => $parts[0],
            'path' => $parts[1],
            'icon' => isset($parts[2]) ? $parts[2] : 'shortcut'
          ];
        }
      }
    }

    // Adjuntar la biblioteca
    $form['#attached']['library'][] = 'quick_shortcuts/quick_shortcuts';

    $form['shortcuts_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Enlaces rápidos'),
      '#prefix' => '<div id="shortcuts-wrapper">',
      '#suffix' => '</div>',
    ];

    $form['shortcuts_wrapper']['shortcuts'] = [
      '#type' => 'table',
      '#header' => [
        $this->t('Título'),
        $this->t('Ruta'),
        $this->t('Icono'),
        $this->t('Operaciones'),
      ],
      '#empty' => $this->t('No hay enlaces configurados.'),
    ];

    // Add existing shortcuts to the form
    if (!empty($shortcuts)) {
      foreach ($shortcuts as $delta => $shortcut) {
        $form['shortcuts_wrapper']['shortcuts'][$delta]['title'] = [
          '#type' => 'textfield',
          '#title' => $this->t('Título'),
          '#title_display' => 'invisible',
          '#default_value' => $shortcut['title'],
          '#required' => TRUE,
        ];
        $form['shortcuts_wrapper']['shortcuts'][$delta]['path'] = [
          '#type' => 'textfield',
          '#title' => $this->t('Ruta'),
          '#title_display' => 'invisible',
          '#default_value' => $shortcut['path'],
          '#required' => TRUE,
        ];
        $form['shortcuts_wrapper']['shortcuts'][$delta]['icon'] = [
          '#type' => 'select',
          '#title' => $this->t('Icono'),
          '#title_display' => 'invisible',
          '#options' => $this->getAvailableIcons(),
          '#default_value' => $shortcut['icon'],
          '#required' => TRUE,
          '#attributes' => ['class' => ['icon-select']],
        ];
        $form['shortcuts_wrapper']['shortcuts'][$delta]['remove'] = [
          '#type' => 'submit',
          '#value' => $this->t('Eliminar'),
          '#name' => 'remove_' . $delta,
          '#submit' => ['::removeCallback'],
          '#ajax' => [
            'callback' => '::updateAjaxCallback',
            'wrapper' => 'shortcuts-wrapper',
          ],
        ];
      }
    }

    $form['shortcuts_wrapper']['add_shortcut'] = [
      '#type' => 'submit',
      '#value' => $this->t('Agregar enlace'),
      '#submit' => ['::addCallback'],
      '#ajax' => [
        'callback' => '::updateAjaxCallback',
        'wrapper' => 'shortcuts-wrapper',
      ],
    ];

    $form['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Posición de la barra'),
      '#options' => [
        'bottom' => $this->t('Centro inferior'),
        'bottom-left' => $this->t('Inferior izquierda'),
        'bottom-right' => $this->t('Inferior derecha'),
      ],
      '#default_value' => $config->get('position') ?: 'bottom',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Ajax callback for the form.
   */
  public function updateAjaxCallback(array &$form, FormStateInterface $form_state) {
    return $form['shortcuts_wrapper'];
  }

  /**
   * Submit handler for adding a new shortcut.
   */
  public function addCallback(array &$form, FormStateInterface $form_state) {
    $shortcuts = $this->config('quick_shortcuts.settings')->get('shortcuts');
    $lines = $shortcuts ? explode("\n", $shortcuts) : [];
    $lines[] = '|';  // Agregar un nuevo enlace vacío
    
    $this->config('quick_shortcuts.settings')
      ->set('shortcuts', implode("\n", $lines))
      ->save();
    
    $form_state->setRebuild();
  }

  /**
   * Submit handler for removing a shortcut.
   */
  public function removeCallback(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    $delta = str_replace('remove_', '', $triggering_element['#name']);
    
    $shortcuts = $this->config('quick_shortcuts.settings')->get('shortcuts');
    $lines = explode("\n", $shortcuts);
    unset($lines[$delta]);
    
    $this->config('quick_shortcuts.settings')
      ->set('shortcuts', implode("\n", $lines))
      ->save();
    
    $form_state->setRebuild();
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $shortcuts = [];
    $values = $form_state->getValue('shortcuts');
    
    if (!empty($values)) {
      foreach ($values as $shortcut) {
        if (!empty($shortcut['title']) && !empty($shortcut['path'])) {
          $shortcuts[] = $shortcut['title'] . '|' . $shortcut['path'] . '|' . $shortcut['icon'];
        }
      }
    }

    $this->config('quick_shortcuts.settings')
      ->set('shortcuts', implode("\n", $shortcuts))
      ->set('position', $form_state->getValue('position'))
      ->save();

    parent::submitForm($form, $form_state);
  }
}
